@@ -62,34 +62,23 @@ import java.util.LinkedHashMap;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
-import org.apache.http.HttpException;
 import org.apache.http.HttpHost;
-import org.apache.http.HttpRequest;
-import org.apache.http.HttpRequestInterceptor;
 import org.apache.http.HttpResponse;
 import org.apache.http.NameValuePair;
 import org.apache.http.StatusLine;
-import org.apache.http.auth.AuthScheme;
-import org.apache.http.auth.AuthScope;
-import org.apache.http.auth.AuthState;
 import org.apache.http.auth.AuthenticationException;
-import org.apache.http.auth.Credentials;
 import org.apache.http.client.ClientProtocolException;
-import org.apache.http.client.CredentialsProvider;
 import org.apache.http.client.HttpResponseException;
 import org.apache.http.client.methods.HttpPost;
 import org.apache.http.client.methods.HttpRequestBase;
-import org.apache.http.client.protocol.ClientContext;
 import org.apache.http.client.utils.URIBuilder;
 import org.apache.http.client.utils.URLEncodedUtils;
 import org.apache.http.entity.ContentType;
 import org.apache.http.entity.InputStreamEntity;
 import org.apache.http.impl.auth.BasicScheme;
-import org.apache.http.impl.client.DefaultHttpClient;
+import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.message.BasicNameValuePair;
 import org.apache.http.protocol.BasicHttpContext;
-import org.apache.http.protocol.ExecutionContext;
-import org.apache.http.protocol.HttpContext;
 import org.json.JSONException;
 import org.json.JSONInputStream;
 import org.json.JSONObject;
@@ -272,7 +261,7 @@ public class WeakforcedClient implements AntiAbuseService {
             Map<String, String> requestParameters = new LinkedHashMap<String, String>(2);
             requestParameters.put("command", "allow");
 
-            JSONObject jBody = new JSONObject(6);
+            JSONObject jBody = new JSONObject(10);
             jBody.put("login", parameters.getLogin());
             jBody.put("remote", parameters.getRemoteAddress());
             jBody.put("pwhash", createPasswordHash(parameters.getLogin(), parameters.getPassword(), secret, algorithm, truncate));
@@ -282,7 +271,8 @@ public class WeakforcedClient implements AntiAbuseService {
             }
             Protocol protocol = parameters.getProtocol();
             if (null != protocol) {
-                jBody.put("protocol", parameters.getProtocol().getName());
+                jBody.put("protocol", protocol.getName());
+                jBody.put("tls", protocol.isSecure());
             }
             Map<String, String> attributes = parameters.getAttributes();
             if (null != attributes && !attributes.isEmpty()) {
@@ -329,7 +319,7 @@ public class WeakforcedClient implements AntiAbuseService {
             Map<String, String> requestParameters = new LinkedHashMap<String, String>(2);
             requestParameters.put("command", "report");
 
-            JSONObject jBody = new JSONObject(8);
+            JSONObject jBody = new JSONObject(10);
             switch (parameters.getReportValue()) {
                 case DENIED_BY_SERVICE:
                     jBody.put("success",  false);
@@ -354,7 +344,8 @@ public class WeakforcedClient implements AntiAbuseService {
             }
             Protocol protocol = parameters.getProtocol();
             if (null != protocol) {
-                jBody.put("protocol", parameters.getProtocol().getName());
+                jBody.put("protocol", protocol.getName());
+                jBody.put("tls", protocol.isSecure());
             }
 
             executePost(WeakforcedCall.REPORT, requestParameters, jBody, VOID);
@@ -474,7 +465,7 @@ public class WeakforcedClient implements AntiAbuseService {
      * @throws ClientProtocolException If client protocol error occurs
      * @throws IOException If an I/O error occurs
      */
-    protected HttpResponse execute(HttpRequestBase method, HttpHost targetHost, DefaultHttpClient httpClient) throws ClientProtocolException, IOException {
+    protected HttpResponse execute(HttpRequestBase method, HttpHost targetHost, CloseableHttpClient httpClient) throws ClientProtocolException, IOException {
         return execute(method, targetHost, httpClient, localcontext);
     }
 
@@ -489,7 +480,7 @@ public class WeakforcedClient implements AntiAbuseService {
      * @throws ClientProtocolException If client protocol error occurs
      * @throws IOException If an I/O error occurs
      */
-    protected HttpResponse execute(HttpRequestBase method, HttpHost targetHost, DefaultHttpClient httpClient, BasicHttpContext context) throws ClientProtocolException, IOException {
+    protected HttpResponse execute(HttpRequestBase method, HttpHost targetHost, CloseableHttpClient httpClient, BasicHttpContext context) throws ClientProtocolException, IOException {
         return httpClient.execute(targetHost, method, context);
     }
 
@@ -594,38 +585,6 @@ public class WeakforcedClient implements AntiAbuseService {
         return WeakforcedExceptionCodes.WEAKFORCED_SERVER_ERROR.create(e, Integer.valueOf(e.getStatusCode()), e.getMessage());
     }
 
-    static class PreemptiveAuth implements HttpRequestInterceptor {
-
-        @Override
-        public void process(HttpRequest request, HttpContext context) throws HttpException, IOException {
-
-            final AuthState authState = (AuthState) context.getAttribute(ClientContext.TARGET_AUTH_STATE);
-
-            // If no auth scheme avaialble yet, try to initialize it preemptively
-            if (authState.getAuthScheme() == null) {
-                final AuthScheme authScheme = (AuthScheme) context.getAttribute("preemptive-auth");
-                final CredentialsProvider credsProvider = (CredentialsProvider) context.getAttribute(ClientContext.CREDS_PROVIDER);
-                final HttpHost targetHost = (HttpHost) context.getAttribute(ExecutionContext.HTTP_TARGET_HOST);
-                if (authScheme != null) {
-                    final Credentials creds = credsProvider.getCredentials(new AuthScope(targetHost.getHostName(), targetHost.getPort()));
-                    if (creds == null) {
-                        throw new HttpException("No credentials for preemptive authentication");
-                    }
-                    authState.setAuthScheme(authScheme);
-                    authState.setCredentials(creds);
-                }
-            }
-        }
-    }
-
-//    public static void main(String[] args) throws Exception {
-//        String pwhash = createPasswordHash("jane.doe", "secret", "123456", "SHA-1", false);
-//        System.out.println(pwhash);
-//
-//        pwhash = createPasswordHash("jane.doe", "secret", "123456", "SHA-1", true);
-//        System.out.println(pwhash);
-//    }
-
     private static String createPasswordHash(String login, String password, String secret, String algorithm, boolean truncate) throws OXException {
         // According to Weakforced proposal: TRUNCATE(SHA256(SECRET + LOGIN + '\x00' + PASSWORD), 12) with 4 0 bits prepended
         byte[] digest = getDigest(new StringBuilder(32).append(secret).append(login).append('\0').append(password).toString(), algorithm);
@@ -713,10 +672,10 @@ public class WeakforcedClient implements AntiAbuseService {
 
         final URI uri;
         final HttpHost targetHost;
-        final DefaultHttpClient httpClient;
+        final CloseableHttpClient httpClient;
         final Endpoint endpoint;
 
-        CallProperties(URI uri, DefaultHttpClient httpClient, HttpHost targetHost, Endpoint endpoint) {
+        CallProperties(URI uri, CloseableHttpClient httpClient, HttpHost targetHost, Endpoint endpoint) {
             super();
             this.uri = uri;
             this.httpClient = httpClient;
