@@ -61,13 +61,10 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicReference;
 import org.apache.http.HttpEntity;
 import org.apache.http.HttpResponse;
-import org.apache.http.auth.AuthScope;
-import org.apache.http.auth.Credentials;
-import org.apache.http.auth.UsernamePasswordCredentials;
 import org.apache.http.client.HttpClient;
 import org.apache.http.client.methods.HttpGet;
 import org.apache.http.client.methods.HttpRequestBase;
-import org.apache.http.impl.client.DefaultHttpClient;
+import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.util.EntityUtils;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
@@ -79,7 +76,6 @@ import com.openexchange.rest.client.endpointpool.EndpointManagerFactory;
 import com.openexchange.rest.client.httpclient.HttpClients;
 import com.openexchange.rest.client.httpclient.HttpClients.ClientConfig;
 import com.openexchange.version.Version;
-import com.openexchange.weakforced.WeakforcedClient.PreemptiveAuth;
 
 /**
  * {@link WeakforcedEndpointManager}
@@ -92,32 +88,26 @@ public class WeakforcedEndpointManager {
     private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(WeakforcedEndpointManager.class);
 
     private static class Entry {
-        final DefaultHttpClient httpClient;
+        final CloseableHttpClient httpClient;
         final EndpointManager endpointManager;
 
-        Entry(DefaultHttpClient httpClient, EndpointManager endpointManager) {
+        Entry(CloseableHttpClient httpClient, EndpointManager endpointManager) {
             super();
             this.httpClient = httpClient;
             this.endpointManager = endpointManager;
         }
     }
 
-    private static DefaultHttpClient newHttpClient(int totalConnections, int maxConnectionsPerRoute, int readTimeout, int connectTimeout, String authLogin, String authPassword) {
+    private static CloseableHttpClient newHttpClient(int totalConnections, int maxConnectionsPerRoute, int readTimeout, int connectTimeout, String authLogin, String authPassword) {
         ClientConfig clientConfig = ClientConfig.newInstance()
             .setUserAgent("OX Weakforced Http Client v" + Version.getInstance().getVersionString())
             .setMaxTotalConnections(totalConnections)
             .setMaxConnectionsPerRoute(maxConnectionsPerRoute)
             .setConnectionTimeout(connectTimeout)
-            .setSocketReadTimeout(readTimeout);
+            .setSocketReadTimeout(readTimeout)
+            .setCredentials(authLogin, authPassword);
 
-        DefaultHttpClient tmp = HttpClients.getHttpClient(clientConfig);
-
-        Credentials credentials = new UsernamePasswordCredentials(authLogin, authPassword);
-        tmp.getCredentialsProvider().setCredentials(AuthScope.ANY, credentials);
-
-        // Add "preemptive-auth" as the first request interceptor
-        tmp.addRequestInterceptor(new PreemptiveAuth(), 0);
-        return tmp;
+        return HttpClients.getHttpClient(clientConfig);
     }
 
     private static Entry entryFor(String endPoints, EndpointManagerFactory factory, String authLogin, String authPassword, StringBuilder propPrefix, ConfigurationService configService) throws OXException {
@@ -138,7 +128,7 @@ public class WeakforcedEndpointManager {
         int connectTimeout = configService.getIntProperty(propPrefix.append("connectTimeout").toString(), 1500);
 
         // Initialize HTTP client
-        DefaultHttpClient httpClient = newHttpClient(totalConnections, maxConnectionsPerRoute, readTimeout, connectTimeout, authLogin, authPassword);
+        CloseableHttpClient httpClient = newHttpClient(totalConnections, maxConnectionsPerRoute, readTimeout, connectTimeout, authLogin, authPassword);
 
         // Setup end-point manager
         EndpointManager endpointManager = factory.createEndpointManager(l, httpClient, AVAILABILITY_STRATEGY, 60, TimeUnit.SECONDS);
